==> cdktf-cdktf-provider-gitlab-6.0.1.tar.gz: package/docs/API.java.md <==
# Submodules <a name="Submodules" id="submodules"></a>

The following submodules are available:
- [applicationSettings](./applicationSettings.java.md)
- [branch](./branch.java.md)
- [branchProtection](./branchProtection.java.md)
- [clusterAgent](./clusterAgent.java.md)
- [clusterAgentToken](./clusterAgentToken.java.md)
- [dataGitlabBranch](./dataGitlabBranch.java.md)
- [dataGitlabClusterAgent](./dataGitlabClusterAgent.java.md)
- [dataGitlabClusterAgents](./dataGitlabClusterAgents.java.md)
- [dataGitlabCurrentUser](./dataGitlabCurrentUser.java.md)
- [dataGitlabGroup](./dataGitlabGroup.java.md)
- [dataGitlabGroupHook](./dataGitlabGroupHook.java.md)
- [dataGitlabGroupHooks](./dataGitlabGroupHooks.java.md)
- [dataGitlabGroupMembership](./dataGitlabGroupMembership.java.md)
- [dataGitlabGroupSubgroups](./dataGitlabGroupSubgroups.java.md)
- [dataGitlabGroupVariable](./dataGitlabGroupVariable.java.md)
- [dataGitlabGroupVariables](./dataGitlabGroupVariables.java.md)
- [dataGitlabGroups](./dataGitlabGroups.java.md)
- [dataGitlabInstanceDeployKeys](./dataGitlabInstanceDeployKeys.java.md)
- [dataGitlabInstanceVariable](./dataGitlabInstanceVariable.java.md)
- [dataGitlabInstanceVariables](./dataGitlabInstanceVariables.java.md)
- [dataGitlabMetadata](./dataGitlabMetadata.java.md)
- [dataGitlabProject](./dataGitlabProject.java.md)
- [dataGitlabProjectBranches](./dataGitlabProjectBranches.java.md)
- [dataGitlabProjectHook](./dataGitlabProjectHook.java.md)
- [dataGitlabProjectHooks](./dataGitlabProjectHooks.java.md)
- [dataGitlabProjectIssue](./dataGitlabProjectIssue.java.md)
- [dataGitlabProjectIssues](./dataGitlabProjectIssues.java.md)
- [dataGitlabProjectMembership](./dataGitlabProjectMembership.java.md)
- [dataGitlabProjectMilestone](./dataGitlabProjectMilestone.java.md)
- [dataGitlabProjectMilestones](./dataGitlabProjectMilestones.java.md)
- [dataGitlabProjectProtectedBranch](./dataGitlabProjectProtectedBranch.java.md)
- [dataGitlabProjectProtectedBranches](./dataGitlabProjectProtectedBranches.java.md)
- [dataGitlabProjectTag](./dataGitlabProjectTag.java.md)
- [dataGitlabProjectTags](./dataGitlabProjectTags.java.md)
- [dataGitlabProjectVariable](./dataGitlabProjectVariable.java.md)
- [dataGitlabProjectVariables](./dataGitlabProjectVariables.java.md)
- [dataGitlabProjects](./dataGitlabProjects.java.md)
- [dataGitlabReleaseLink](./dataGitlabReleaseLink.java.md)
- [dataGitlabReleaseLinks](./dataGitlabReleaseLinks.java.md)
- [dataGitlabRepositoryFile](./dataGitlabRepositoryFile.java.md)
- [dataGitlabRepositoryTree](./dataGitlabRepositoryTree.java.md)
- [dataGitlabUser](./dataGitlabUser.java.md)
- [dataGitlabUserSshkeys](./dataGitlabUserSshkeys.java.md)
- [dataGitlabUsers](./dataGitlabUsers.java.md)
- [deployKey](./deployKey.java.md)
- [deployKeyEnable](./deployKeyEnable.java.md)
- [deployToken](./deployToken.java.md)
- [group](./group.java.md)
- [groupAccessToken](./groupAccessToken.java.md)
- [groupBadge](./groupBadge.java.md)
- [groupCluster](./groupCluster.java.md)
- [groupCustomAttribute](./groupCustomAttribute.java.md)
- [groupHook](./groupHook.java.md)
- [groupLabel](./groupLabel.java.md)
- [groupLdapLink](./groupLdapLink.java.md)
- [groupMembership](./groupMembership.java.md)
- [groupProjectFileTemplate](./groupProjectFileTemplate.java.md)
- [groupSamlLink](./groupSamlLink.java.md)
- [groupShareGroup](./groupShareGroup.java.md)
- [groupVariable](./groupVariable.java.md)
- [instanceCluster](./instanceCluster.java.md)
- [instanceVariable](./instanceVariable.java.md)
- [label](./label.java.md)
- [managedLicense](./managedLicense.java.md)
- [pagesDomain](./pagesDomain.java.md)
- [personalAccessToken](./personalAccessToken.java.md)
- [pipelineSchedule](./pipelineSchedule.java.md)
- [pipelineScheduleVariable](./pipelineScheduleVariable.java.md)
- [pipelineTrigger](./pipelineTrigger.java.md)
- [project](./project.java.md)
- [projectAccessToken](./projectAccessToken.java.md)
- [projectApprovalRule](./projectApprovalRule.java.md)
- [projectBadge](./projectBadge.java.md)
- [projectCluster](./projectCluster.java.md)
- [projectCustomAttribute](./projectCustomAttribute.java.md)
- [projectEnvironment](./projectEnvironment.java.md)
- [projectFreezePeriod](./projectFreezePeriod.java.md)
- [projectHook](./projectHook.java.md)
- [projectIssue](./projectIssue.java.md)
- [projectIssueBoard](./projectIssueBoard.java.md)
- [projectLevelMrApprovals](./projectLevelMrApprovals.java.md)
- [projectMembership](./projectMembership.java.md)
- [projectMilestone](./projectMilestone.java.md)
- [projectMirror](./projectMirror.java.md)
- [projectProtectedEnvironment](./projectProtectedEnvironment.java.md)
- [projectRunnerEnablement](./projectRunnerEnablement.java.md)
- [projectShareGroup](./projectShareGroup.java.md)
- [projectTag](./projectTag.java.md)
- [projectVariable](./projectVariable.java.md)
- [provider](./provider.java.md)
- [releaseLink](./releaseLink.java.md)
- [repositoryFile](./repositoryFile.java.md)
- [runner](./runner.java.md)
- [serviceEmailsOnPush](./serviceEmailsOnPush.java.md)
- [serviceExternalWiki](./serviceExternalWiki.java.md)
- [serviceGithub](./serviceGithub.java.md)
- [serviceJira](./serviceJira.java.md)
- [serviceMicrosoftTeams](./serviceMicrosoftTeams.java.md)
- [servicePipelinesEmail](./servicePipelinesEmail.java.md)
- [serviceSlack](./serviceSlack.java.md)
- [systemHook](./systemHook.java.md)
- [tagProtection](./tagProtection.java.md)
- [topic](./topic.java.md)
- [user](./user.java.md)
- [userCustomAttribute](./userCustomAttribute.java.md)
- [userGpgkey](./userGpgkey.java.md)
- [userSshkey](./userSshkey.java.md)

==> cdktf-cdktf-provider-gitlab-6.0.2.tar.gz: package/docs/API.java.md <==
# Submodules <a name="Submodules" id="submodules"></a>

The following submodules are available:
- [application](./application.java.md)
- [applicationSettings](./applicationSettings.java.md)
- [branch](./branch.java.md)
- [branchProtection](./branchProtection.java.md)
- [clusterAgent](./clusterAgent.java.md)
- [clusterAgentToken](./clusterAgentToken.java.md)
- [dataGitlabApplication](./dataGitlabApplication.java.md)
- [dataGitlabBranch](./dataGitlabBranch.java.md)
- [dataGitlabClusterAgent](./dataGitlabClusterAgent.java.md)
- [dataGitlabClusterAgents](./dataGitlabClusterAgents.java.md)
- [dataGitlabCurrentUser](./dataGitlabCurrentUser.java.md)
- [dataGitlabGroup](./dataGitlabGroup.java.md)
- [dataGitlabGroupHook](./dataGitlabGroupHook.java.md)
- [dataGitlabGroupHooks](./dataGitlabGroupHooks.java.md)
- [dataGitlabGroupMembership](./dataGitlabGroupMembership.java.md)
- [dataGitlabGroupSubgroups](./dataGitlabGroupSubgroups.java.md)
- [dataGitlabGroupVariable](./dataGitlabGroupVariable.java.md)
- [dataGitlabGroupVariables](./dataGitlabGroupVariables.java.md)
- [dataGitlabGroups](./dataGitlabGroups.java.md)
- [dataGitlabInstanceDeployKeys](./dataGitlabInstanceDeployKeys.java.md)
- [dataGitlabInstanceVariable](./dataGitlabInstanceVariable.java.md)
- [dataGitlabInstanceVariables](./dataGitlabInstanceVariables.java.md)
- [dataGitlabMetadata](./dataGitlabMetadata.java.md)
- [dataGitlabProject](./dataGitlabProject.java.md)
- [dataGitlabProjectBranches](./dataGitlabProjectBranches.java.md)
- [dataGitlabProjectHook](./dataGitlabProjectHook.java.md)
- [dataGitlabProjectHooks](./dataGitlabProjectHooks.java.md)
- [dataGitlabProjectIssue](./dataGitlabProjectIssue.java.md)
- [dataGitlabProjectIssues](./dataGitlabProjectIssues.java.md)
- [dataGitlabProjectMembership](./dataGitlabProjectMembership.java.md)
- [dataGitlabProjectMilestone](./dataGitlabProjectMilestone.java.md)
- [dataGitlabProjectMilestones](./dataGitlabProjectMilestones.java.md)
- [dataGitlabProjectProtectedBranch](./dataGitlabProjectProtectedBranch.java.md)
- [dataGitlabProjectProtectedBranches](./dataGitlabProjectProtectedBranches.java.md)
- [dataGitlabProjectTag](./dataGitlabProjectTag.java.md)
- [dataGitlabProjectTags](./dataGitlabProjectTags.java.md)
- [dataGitlabProjectVariable](./dataGitlabProjectVariable.java.md)
- [dataGitlabProjectVariables](./dataGitlabProjectVariables.java.md)
- [dataGitlabProjects](./dataGitlabProjects.java.md)
- [dataGitlabReleaseLink](./dataGitlabReleaseLink.java.md)
- [dataGitlabReleaseLinks](./dataGitlabReleaseLinks.java.md)
- [dataGitlabRepositoryFile](./dataGitlabRepositoryFile.java.md)
- [dataGitlabRepositoryTree](./dataGitlabRepositoryTree.java.md)
- [dataGitlabUser](./dataGitlabUser.java.md)
- [dataGitlabUserSshkeys](./dataGitlabUserSshkeys.java.md)
- [dataGitlabUsers](./dataGitlabUsers.java.md)
- [deployKey](./deployKey.java.md)
- [deployKeyEnable](./deployKeyEnable.java.md)
- [deployToken](./deployToken.java.md)
- [group](./group.java.md)
- [groupAccessToken](./groupAccessToken.java.md)
- [groupBadge](./groupBadge.java.md)
- [groupCluster](./groupCluster.java.md)
- [groupCustomAttribute](./groupCustomAttribute.java.md)
- [groupHook](./groupHook.java.md)
- [groupLabel](./groupLabel.java.md)
- [groupLdapLink](./groupLdapLink.java.md)
- [groupMembership](./groupMembership.java.md)
- [groupProjectFileTemplate](./groupProjectFileTemplate.java.md)
- [groupSamlLink](./groupSamlLink.java.md)
- [groupShareGroup](./groupShareGroup.java.md)
- [groupVariable](./groupVariable.java.md)
- [instanceCluster](./instanceCluster.java.md)
- [instanceVariable](./instanceVariable.java.md)
- [label](./label.java.md)
- [managedLicense](./managedLicense.java.md)
- [pagesDomain](./pagesDomain.java.md)
- [personalAccessToken](./personalAccessToken.java.md)
- [pipelineSchedule](./pipelineSchedule.java.md)
- [pipelineScheduleVariable](./pipelineScheduleVariable.java.md)
- [pipelineTrigger](./pipelineTrigger.java.md)
- [project](./project.java.md)
- [projectAccessToken](./projectAccessToken.java.md)
- [projectApprovalRule](./projectApprovalRule.java.md)
- [projectBadge](./projectBadge.java.md)
- [projectCluster](./projectCluster.java.md)
- [projectCustomAttribute](./projectCustomAttribute.java.md)
- [projectEnvironment](./projectEnvironment.java.md)
- [projectFreezePeriod](./projectFreezePeriod.java.md)
- [projectHook](./projectHook.java.md)
- [projectIssue](./projectIssue.java.md)
- [projectIssueBoard](./projectIssueBoard.java.md)
- [projectLevelMrApprovals](./projectLevelMrApprovals.java.md)
- [projectMembership](./projectMembership.java.md)
- [projectMilestone](./projectMilestone.java.md)
- [projectMirror](./projectMirror.java.md)
- [projectProtectedEnvironment](./projectProtectedEnvironment.java.md)
- [projectRunnerEnablement](./projectRunnerEnablement.java.md)
- [projectShareGroup](./projectShareGroup.java.md)
- [projectTag](./projectTag.java.md)
- [projectVariable](./projectVariable.java.md)
- [provider](./provider.java.md)
- [releaseLink](./releaseLink.java.md)
- [repositoryFile](./repositoryFile.java.md)
- [runner](./runner.java.md)
- [serviceCustomIssueTracker](./serviceCustomIssueTracker.java.md)
- [serviceEmailsOnPush](./serviceEmailsOnPush.java.md)
- [serviceExternalWiki](./serviceExternalWiki.java.md)
- [serviceGithub](./serviceGithub.java.md)
- [serviceJira](./serviceJira.java.md)
- [serviceMicrosoftTeams](./serviceMicrosoftTeams.java.md)
- [servicePipelinesEmail](./servicePipelinesEmail.java.md)
- [serviceSlack](./serviceSlack.java.md)
- [systemHook](./systemHook.java.md)
- [tagProtection](./tagProtection.java.md)
- [topic](./topic.java.md)
- [user](./user.java.md)
- [userCustomAttribute](./userCustomAttribute.java.md)
- [userGpgkey](./userGpgkey.java.md)
- [userSshkey](./userSshkey.java.md)
